.. termlog documentation master file, created by
   sphinx-quickstart on Thu Jun  6 09:16:40 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to termlog's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   license
   installation
   usage
   contributing
   changes
   api
   authors


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
